from .util import *
from .colgen import *
from .dtaapi import *

# print out the current version
print('path4gmns, version 0.6.0')